#
# This is the SPEC file for creating binary and source RPMs for the VMs.
#
#
# The Qubes OS Project, http://www.qubes-os.org
#
# Copyright (C) 2011  Marek Marczykowski <marmarek@invisiblethingslab.com>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#
#

# enable python3 by default
%bcond_without python3

# python2 is not available on RHEL > 7 and not needed on Fedora > 28
%if 0%{?rhel} > 7 || 0%{?fedora} > 28
# disable python2 by default
%bcond_with python2
%else
%bcond_without python2
%endif


Name:		qubes-gpg-split-dom0
Version:	2.0.58
Release:	1%{dist}
Summary:    Qubes policy for gpg split

Group:		Qubes
Vendor:		Invisible Things Lab
License:	GPL
URL:		http://www.qubes-os.org

BuildRequires: make
%if %{with python2}
BuildRequires: python-setuptools
BuildRequires: python2-rpm-macros
%endif
%if %{with python3}
BuildRequires: python3-rpm-macros
BuildRequires: python3-setuptools
BuildRequires: python3-devel
%endif
Requires:	gpg

Source0: qubes-gpg-split-%{version}.tar.gz

%description

%prep
%setup -q -n qubes-gpg-split-%{version}

%install
rm -rf $RPM_BUILD_ROOT
install -m 0664 -D qubes.Gpg.policy $RPM_BUILD_ROOT/etc/qubes-rpc/policy/qubes.Gpg
install -m 0664 -D qubes.GpgImportKey.policy $RPM_BUILD_ROOT/etc/qubes-rpc/policy/qubes.GpgImportKey
%{?with_python2:make -C tests install-dom0-py2 DESTDIR=$RPM_BUILD_ROOT PYTHON2=%{__python2}}
%{?with_python3:make -C tests install-dom0-py3 DESTDIR=$RPM_BUILD_ROOT PYTHON2=%{__python3}}

%clean
rm -rf $RPM_BUILD_ROOT

%files
%config(noreplace) %attr(0664,root,qubes) /etc/qubes-rpc/policy/qubes.Gpg
%config(noreplace) %attr(0664,root,qubes) /etc/qubes-rpc/policy/qubes.GpgImportKey
%if %{with python2}
%dir %{python2_sitelib}/splitgpg-*.egg-info
%{python2_sitelib}/splitgpg-*.egg-info/*
%{python2_sitelib}/splitgpg
%endif
%if %{with python3}
%dir %{python3_sitelib}/splitgpg-*.egg-info
%{python3_sitelib}/splitgpg-*.egg-info/*
%{python3_sitelib}/splitgpg
%endif

%changelog
* Sat Apr 02 2022 Qubes OS Team <qubes-devel@googlegroups.com>
- For complete changelog see: https://github.com/QubesOS/qubes-app-linux-split-gpg.git

* Sat Apr 02 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 338d3c4
- version 2.0.58

* Sat Mar 26 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - c03c30a
- Fix list and verify option processing

* Sat Mar 26 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - c4a180f
- Drop --pgp2

* Sat Mar 26 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - ea7df21
- Reject options ignored by the wrapper script

* Sun Mar 06 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - a652de5
- test: avoid false negative from sending status dialog

* Mon Feb 28 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - bd3b0bf
- version 2.0.57

* Sun Feb 27 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - b5c4aed
- Allow --attribute-fd

* Sun Feb 27 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 72bab32
- Fix remaining hangs

* Sun Feb 27 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - b528828
- process_io(): block SIGCHLD

* Sun Feb 27 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - abcff74
- process_out(): treat an empty FD_SET properly

* Sun Feb 27 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 702461f
- Set empty handler for SIGPIPE

* Sun Feb 27 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 1462db1
- Use _exit(), not exit(), in the child after fork()

* Sun Feb 27 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - b7e755f
- Use _Bool for a type that must always be 0 or 1

* Sun Feb 27 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - a9dc9cc
- Use pipe2(O_CLOEXEC) instead of closing fds

* Sun Feb 27 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - e4a4a21
- Avoid closing a needed file descriptor

* Sun Feb 27 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - cf56dac
- Fix assertion for new file descriptor limit

* Sun Feb 27 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 7361828
- Open signature file with O_CLOEXEC and O_NOCTTY

* Sun Feb 27 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 1cb1969
- Properly validate file descriptor arguments

* Sun Feb 27 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 899e3d4
- Avoid out of bounds access to closed_fds

* Fri Feb 25 2022 Patrick Schleizer <adrelanos@whonix.org> - e148764
- Update gpg-client-wrapper

* Fri Feb 25 2022 Patrick Schleizer <adrelanos@whonix.org> - 29976c5
- add alias `--sign-with` to `-u`

* Tue Feb 15 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 42c2314
- Harden move_fds against bad file descriptor values

* Mon Feb 14 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 8e021a3
- version 2.0.56

* Mon Feb 14 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 49b70ad
- Sanitize arguments to --list-options

* Mon Feb 14 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - a3a8c36
- Prevent GPG from launching a photo viewer

* Fri Feb 11 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 40a1d3b
- `--output` is more than just stdout redirection

* Fri Feb 11 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 5b53dd3
- Use set_output for -o as well as --output

* Fri Feb 11 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 5aa66e6
- Recognize -o in addition to --output

* Fri Feb 11 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 655bc12
- Reject non-UTF-8 compatible display charsets

* Fri Feb 11 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 9d7b246
- Allow `--utf8-strings`

* Fri Feb 11 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 99f19b0
- Ignore various options used by Mailpile

* Thu Feb 10 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 54a010e
- Ditch pipecat and fix hangs

* Mon Feb 07 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - af96037
- Fix the Arch build

* Sat Feb 05 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 850e19d
- More robust file descriptor handling

* Thu Feb 03 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - f393809
- Allow --with-secret

* Thu Feb 03 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - ff31021
- Ignore several options used by kmail

* Thu Feb 03 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - aaec233
- Forcibly disable dirmngr

* Thu Feb 03 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - a9f57be
- Allow '--clear-sign' as well as '--clearsign'

* Wed Feb 02 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - abb7c47
- Translate ‘--detach-sig’ to ‘--detach-sign’

* Wed Jan 05 2022 deeplow <deeplower@protonmail.com> - 7f7211c
- undo removal of resetting dogtail search count

* Tue Jan 04 2022 deeplow <deeplower@protonmail.com> - 64ec898
- merge timeout approaches

* Tue Jan 04 2022 deeplow <deeplower@protonmail.com> - ec7c116
- print failed to send error

* Tue Jan 04 2022 deeplow <deeplower@protonmail.com> - 9352933
- tests: earlier detection of failed message sending

* Fri Dec 24 2021 deeplow <deeplower@protonmail.com> - 7ecdcf7
- tests: reduce whonix boot clock rand during testing

* Sun Dec 12 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 3ad9aee
- version 2.0.55

* Sun Dec 12 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 5fe4133
- Do not use fancy unicode quotes

* Thu Dec 09 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - e280dc0
- Avoid mishandling empty strings

* Thu Dec 09 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - 47ac258
- Consolidate redundant case branches

* Thu Dec 09 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - 0cbea15
- Use bash's [[ consistently

* Thu Dec 09 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - df81022
- Convert --detach into --detach-sign

